@@ -11,24 +11,21 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h 11156 2011-07-27 14:17:02Z doligez $ */
-
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
 
-#undef ARCH_SIXTYFOUR
+#define ARCH_SIXTYFOUR
 #define SIZEOF_INT 4
-#define SIZEOF_LONG 4
-#define SIZEOF_PTR 4
+#define SIZEOF_LONG 8
+#define SIZEOF_PTR 8
 #define SIZEOF_SHORT 2
-#define ARCH_INT64_TYPE long long
-#define ARCH_UINT64_TYPE unsigned long long
-#define ARCH_INT64_PRINTF_FORMAT "ll"
+#define ARCH_INT64_TYPE long
+#define ARCH_UINT64_TYPE unsigned long
+#define ARCH_INT64_PRINTF_FORMAT "l"
 #define ARCH_BIG_ENDIAN
 #undef ARCH_ALIGN_DOUBLE
 #undef ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
-#define ASM_CFI_SUPPORTED
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
 #define POSIX_SIGNALS
@@ -150,7 +147,8 @@ typedef struct { uint32 l, h; } uint64, int64;
 /* We use threaded code interpretation if the compiler provides labels
    as first-class values (GCC 2.x). */
 
-#if defined(__GNUC__) && __GNUC__ >= 2 && !defined(DEBUG) && !defined (SHRINKED_GNUC) && !defined(CAML_JIT)
+#if defined(__GNUC__) && __GNUC__ >= 2 && !defined(DEBUG) \
+    && !defined (SHRINKED_GNUC) && !defined(CAML_JIT)
 #define THREADED_CODE
 #endif
 
