@@ -11,8 +11,6 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: misc.h 11156 2011-07-27 14:17:02Z doligez $ */
-
 /* Miscellaneous macros and variables. */
 
 #ifndef CAML_MISC_H
@@ -50,6 +48,14 @@ typedef size_t asize_t;
 #define CAMLprim
 #define CAMLextern extern
 
+/* Weak function definitions that can be overriden by external libs */
+/* Conservatively restricted to ELF and MacOSX platforms */
+#if defined(__GNUC__) && (defined (__ELF__) || defined(__APPLE__))
+#define CAMLweakdef __attribute__((weak))
+#else
+#define CAMLweakdef
+#endif
+
 /* Assertions */
 
 
